@@ -1,10 +1,14 @@
-# $Id: Literal.pm,v 1.5 2000/01/25 16:33:54 matt Exp $
+# $Id: Literal.pm,v 1.6 2000/03/20 14:46:29 matt Exp $
 
 package XML::XPath::Literal;
 use XML::XPath::Boolean;
 use XML::XPath::Number;
 use strict;
 
+use overload 
+		'""' => \&value,
+		'cmp' => \&cmp;
+
 sub new {
 	my $class = shift;
 	my ($string) = @_;
@@ -27,6 +31,12 @@ sub value {
 	$$self;
 }
 
+sub cmp {
+	my $self = shift;
+	my ($cmp) = @_;
+	$$self cmp $cmp;
+}
+
 sub evaluate {
 	my $self = shift;
 	$self;
