@@ -1,10 +1,13 @@
-# $Id: NodeSet.pm,v 1.5 2000/03/20 14:55:28 matt Exp $
+# $Id: NodeSet.pm,v 1.6 2000/04/17 11:14:25 matt Exp $
 
 package XML::XPath::NodeSet;
 use strict;
 
 use XML::XPath::Boolean;
 
+use overload 
+		'""' => \&to_literal;
+
 sub new {
 	my $class = shift;
 	bless [], $class;
@@ -72,4 +75,11 @@ sub to_literal {
 			);
 }
 
+sub to_number {
+	my $self = shift;
+	return XML::XPath::Number->new(
+			$self->to_literal
+			);
+}
+
 1;
